NameScore = NameScore or {}
NameScoreAdds = {}
NameScoreSorted = {}

local NAMESCORE_DEBUG = true

local grade

local holdTable = {}

local syncFrame = CreateFrame("Frame")
syncFrame:Hide()
syncFrame:RegisterEvent("CHAT_MSG_ADDON")
syncFrame:SetScript("OnEvent", function(self, event, prefix, message, channel, sender)
	if prefix == "NAMESCORE" then
		if message == "request" then
			print("Received a message to sync from "..sender)
			syncFrame.sender = sender
			for k, v in pairs(NameScoreAdds) do
				tinsert(holdTable, {v[1], v[2], v[3]})
			end
			print("Copied the stored data to the temporary holding bin.")
			SendAddonMessage("NAMESCORE", "counting:"..#holdTable, "WHISPER", sender)
			syncFrame:Show()
		elseif message == "confirm received" then
			NameScoreAdds = {}
		elseif message == "sent last" then
			SendAddonMessage("NAMESCORE", "confirm received", "WHISPER", sender)
			print("Finished receiving data from "..sender)
		elseif message:match("sendinginfo") then
			local name, race, class = message:match("sendinginfo:(%P+):(%P+):(%P+)")
			tinsert(NameScoreAdds, {name, race, class})
		elseif message:match("counting") then
			print("Preparing to receive "..message:match(":(%d+)").." names from "..sender)
		end
	end
end)

syncFrame:SetScript("OnUpdate", function(self, elapsed)
	self.timer = (self.timer or 0) + elapsed
	if self.timer >= 0.1 then
		if #holdTable == 0 then
			SendAddonMessage("NAMESCORE", "sent last", "WHISPER", self.sender)
			print("Finished sending to "..self.sender)
			self:Hide()
			self.timer = 0
			return
		end
		self.timer = 0
		local combinedinfo = "sendinginfo:"..holdTable[#holdTable][1]..":"..holdTable[#holdTable][2]..":"..holdTable[#holdTable][3]
		SendAddonMessage("NAMESCORE", combinedinfo, "WHISPER", self.sender)
		holdTable[#holdTable] = nil
	end
end)

local letters, consonants, vowels, euros, breakdown, recycleMe = {}, {}, {}, {}, {}, {}
local numV, numC, numE, numL

local origFunc = GameTooltip:GetScript("OnTooltipSetUnit")

local function OnTooltipSetUnit(frame, ...)
	local name, unit = frame:GetUnit()
	if UnitIsPlayer(unit) then
		local score = NameScore.CalculateScore(name, unit) / 10
		local r, g = (( 100 - score ) / 40), ( score - 60 ) / 40
		if r < 0 then
			r = 0
		end
		if g < 0 then
			g = 0
		end
		for k, v in pairs(NameScore.Grades) do
			if score >= v[1] then
				grade = v[2]
			end
		end
		if not grade then
			grade = "F"
		end
		frame:AddDoubleLine("NameScore:", format("%.2f %s", score, grade), 0, 0.6, 1, r, g, 0)
	end
	return origFunc(frame, ...)
end

function NameScore.CalculateScore(name, unit, expl)
	for _, v in pairs({letters, consonants, vowels, euros, breakdown}) do
		wipe(v)
	end
	
	name = strlower(name)
	
	local class = select(2,UnitClass(unit))
	local race = select(2,UnitRace(unit))
	local score = 0
	
	for letter in name:gmatch("([%z\1-\127\194-\244][\128-\191]*)") do
		tinsert(letters, letter)
		if NameScore.Consonants[letter] then
			tinsert(consonants, NameScore.Consonants[letter])
		elseif NameScore.Vowels[letter] then
			tinsert(vowels, NameScore.Vowels[letter])
		else
			tinsert(euros, letter)
			if NameScore.Vowels[NameScore.Foreign[letter]] then
				tinsert(vowels, NameScore.Foreign[letter])
			else
				tinsert(consonants, NameScore.Foreign[letter])
			end
		end
	end
	
	for k, v in pairs(euros) do
		name = string.gsub(name, v, NameScore.Foreign[v])
	end
	
	numV, numC, numE, numL = #vowels, #consonants, #euros, #letters
	
	NameScore.Legibility(name)
	NameScore.Appropriateness(name, class, race)
	NameScore.Aesthetics(name)
	NameScore.Miscellaneous(name)
	
	for k, v in pairs(breakdown) do
		if v[2] then
			score = score + v[2]
		end
	end
	
	return score

end

GameTooltip:SetScript("OnTooltipSetUnit", OnTooltipSetUnit)

function NameScore.Legibility(name)
	if numE >= 3 then -- pts off for foreign characters
		tinsert(breakdown, {"3 or more foreign characters: 0 / 180 pts.", 0})
	elseif numE == 2 then
		tinsert(breakdown, {"2 foreign characters: 30 / 180 pts.", 30})
	elseif numE == 1 then
		tinsert(breakdown, {"1 foreign character: 90 / 180 pts.", 90})
	else
		tinsert(breakdown, {"No foreign characters: 180 / 180 pts.", 180})
	end
	do -- calculate the ratio of consonants to vowels
		local ratio = (numV ~= 0 and (numC / numV)) or 0
		local diff = math.abs(ratio - (2.5))
		local deviation = math.floor(diff / 0.2)
		local subtractedScore = deviation * 5
		local finalScore = 45 - subtractedScore
		if finalScore < 0 then
			finalScore = 0
		end
		tinsert(breakdown, {format("Ratio of consonants to vowels\n   is %.2f:  %.1f / 45 pts.", ratio, finalScore), finalScore})
	end
	do -- check for strings of vowels
		local vCheck
		for pos = 1, (numL - 3) do
			if NameScore.Vowels[letters[pos]] and NameScore.Vowels[letters[pos+1]] and NameScore.Vowels[letters[pos+2]] then
				if NameScore.Vowels[letters[pos+3]] then
					tinsert(breakdown, {"Four vowels in a row:  0 / 50 pts.", 0})
					vCheck = true
					break
				else
					tinsert(breakdown, {"Three vowels in a row: 25 / 50 pts.", 25})
					vCheck = true
					break
				end
			end
		end
		if not vCheck then
			tinsert(breakdown, {"No consecutive groups of vowels\n   longer than two in a row: 50 / 50 pts.", 50})
		end
	end
	do -- check for strings of consonants
		local cCheck
		for pos = 1, (numL >= 5 and (numL - 4) or 1) do
			if NameScore.Consonants[letters[pos]] and NameScore.Consonants[letters[pos+1]] and NameScore.Consonants[letters[pos+2]] then
				if NameScore.Consonants[letters[pos+3]] then
					if NameScore.Consonants[letters[pos+4]] then
						tinsert(breakdown, {"Five consonants in a row:  0 / 25 pts.", 0})
						cCheck = true
						break
					else
						tinsert(breakdown, {"Four consonants in a row: 5 / 25 pts.", 5})
						cCheck = true
						break
					end
				else
					tinsert(breakdown, {"Three consonants in a row: 15 / 25 pts.", 15})
					cCheck = true
					break
				end
			end
		end
		if not cCheck then
			tinsert(breakdown, {"No consecutive groups of consonants\n   longer than two in a row: 25 / 25 pts.", 25})
		end
	end
end

function NameScore.Appropriateness(name, class, race)
	wipe(recycleMe)
	do -- check for matches against the immature names
		local failNames = 0
		for k, v in pairs(NameScore.ImmatureNames) do
			if strfind(name, v) then
				failNames = failNames + 1
				tinsert(recycleMe, v)
			end
		end
		if failNames >= 1 then
			tinsert(breakdown, {format("The name contains the following\n   immature language: "..strjoin(",", unpack(recycleMe))..".  %d / 160 pts.", (failNames > 1 and -40) or (failNames == 1 and 0)), (failNames > 1 and -40) or (failNames == 1 and 0)})
		else
			tinsert(breakdown, {"At this point in time, no immature\n   language detected.  160 / 160 pts.", 160})
		end
	end
	wipe(recycleMe)
	do -- check for matches against plain stupid names
		local stupidNames = 0
		for k, v in pairs(NameScore.PlainStupid) do
			if strfind(name, v[1]) then
				if v[2]["ALL"] then
					stupidNames = stupidNames + 1
					tinsert(recycleMe, v[1])
				end
			end
		end
		if stupidNames >= 1 then
			tinsert(breakdown, {format("The name contains the following language inappropriate\n   for an RPG: "..strjoin(",", unpack(recycleMe))..".  %d / 120 pts.", (stupidNames > 1 and -30) or (stupidNames == 1 and 0), (stupidNames > 1 and -30) or (stupidNames == 1 and 0))})
		else
			tinsert(breakdown, {"At this point in time, no language inappropriate\n   for an RPG detected.  120 / 120 pts.", 120})
		end
	end
	wipe(recycleMe)
	do -- check for matches against class / race names
		local classRaceNames = 0
		for k, v in pairs(NameScore.PlainStupid) do
			if strfind(name, v[1]) then
				if v[3][race] then
					classRaceNames = classRaceNames + 1
					tinsert(recycleMe, v[1])
				end
			end
		end
		for k, v in pairs(NameScore.PlainStupid) do
			if strfind(name, v[1]) then
				if v[2][class] then
					classRaceNames = classRaceNames + 1
					tinsert(recycleMe, v[1])
				end
			end
		end
		if classRaceNames >= 1 then
			tinsert(breakdown, {format("The name contains the following reference(s)\n   to the race or class: "..strjoin(",", unpack(recycleMe))..".  %d / 100 pts.", (classRaceNames > 1 and -25) or (classRaceNames == 1 and 0)), (classRaceNames > 1 and - 25) or (classRaceNames == 1 and 0)})
		else
			tinsert(breakdown, {"At this point in time, no reference to\n   race or class detected.  100 / 100 pts.", 100})
		end
	end
	do -- check for matches against fantasy names
		local fantNames = 0
		for k, v in pairs(NameScore.Fantasy) do
			if strfind(name, v) then
				fantNames = fantNames + 1
				tinsert(recycleMe, v)
			end
		end
		if fantNames >= 1 then
			tinsert(breakdown, {"The name contains the following reference(s) to an\n   established fantasy figure: "..strjoin(",", unpack(recycleMe))..".  0 / 20 pts.", 0})
		else
			tinsert(breakdown, {"At this point in time, no reference to\n   established fantasy names detected.  20 / 20 pts.", 20})
		end
	end
end

function NameScore.Aesthetics(name)
	do -- check for beginning fricatives
		local fricCheck
		for k, v in pairs({"f", "v", "th", "s", "z"}) do
			local pos = strfind(strlower(name), v)
			if pos == 1 then
				fricCheck = k
				break
			end
		end
		if fricCheck then
			tinsert(breakdown, {format("Names beginning with a fricative (%s)\n   are rough to the ear.  0 / 50 pts.", ({"f", "v", "th", "s", "z"})[fricCheck]), 0})
		else
			tinsert(breakdown, {"Harmonious sounds at the beginning\n   of the name.  50 / 50 pts.", 50})
		end
	end
	do -- check for ending plosives
		local plosCheck
		for k, v in pairs({"p", "b", "t", "d"}) do
			local pos = strfind(strlower(name), v)
			if pos == strlen(name) then
				plosCheck = k
				break
			end
		end
		if plosCheck then
			tinsert(breakdown, {format("Names ending with a plosive (%s)\n   come to a harsh stop.  0 / 50 pts.", ({"p", "b", "t", "d"})[plosCheck]), 0})
		else
			tinsert(breakdown, {"The name transitions to a smooth\n   ending sound.  50 / 50 pts.", 50})
		end
	end
	do -- check for q without u
		if strfind(strlower(name), "q") then
			local pos = strfind(strlower(name), "q")
			if pos == strlen(name) or strfind(strlower(name), "u") ~= (pos + 1) then
				tinsert(breakdown, {"The name contains a Q without a U\n   immediately following it.  0 / 50 pts.", 0})
			else
				tinsert(breakdown, {"The name's Q is followed by\n   a U.  50 / 50 pts.", 50})
			end
		else
			tinsert(breakdown, {"No Q in the name so free pts as if you\n   used a Q followed by a U (for now.)  50 / 50 pts.", 50})
		end
	end
	do -- check for repeating sequences
		local sequence, matches = #letters - 1, 0
		wipe(recycleMe)
		for i = 1, sequence do
			recycleMe[i]=strlower(strsub(name, i, i+1))
		end
		for i = 1, sequence do
			local sub = recycleMe[i]
			for k, v in pairs(recycleMe) do
				if v==sub and k>i then
					matches = matches + 1
				end
			end
		end
		tinsert(breakdown, {format("%s of letter pairs\n   in the name: %d / 50 pts", (matches >= 2 and "Two or more repetitions") or (matches == 1 and "One repetition") or "No repetitions", (matches >= 2 and 0) or (matches == 1 and 10) or 50), (matches >= 2 and 0) or (matches == 1 and 10) or 50})
	end
end

function NameScore.Miscellaneous(name)
	-- check for two or more X or Z
	local xCount, zCount = 0, 0
	for i = 1, #letters do
		if letters[i] == "x" then
			xCount = xCount + 1
		elseif letters[i] == "z" then
			zCount = zCount + 1
		end
	end
	local xzJudge = (xCount >= 2 and "Two instances of the letter x") or (zCount >= 2 and "2 instances of the letter z") or "Zero or one of both Xs and Zs"
	tinsert(breakdown, {format("%s are\n   present in the name: %d / 25 pts.", xzJudge, (xzJudge ~= "Zero or one of both Xs and Zs" and 0 or 25)), xzJudge ~= "Zero or one of both Xs and Zs" and 0 or 25})
	-- check for palindromes
	local palindrome = (string.reverse(name) == name)
	tinsert(breakdown, {format("%s: %d / 25 pts.", (palindrome and "The name is a palindrome (which is\n   not as clever as most people think)") or "The name is not a palindrome (a good thing;\n   palindromes aren't that clever)", (palindrome and 0) or 25), palindrome and 0 or 25})
	-- check for same beginning and ending letter
	local firstLast = (letters[1] == letters[#letters])
	tinsert(breakdown, {format("The first and last letter are %s: %d / 25 pts.", firstLast and "the same" or "different", firstLast and 0 or 25), firstLast and 0 or 25})
	-- check for ending in X or Z
	local lastXorZ = (letters[#letters] == "x" or letters[#letters] == "z")
	tinsert(breakdown, {format("The last letter %s an X or a Z (poor plural\n   forming skills, or trying to make up for the fact\n   that the original name was taken): %d / 25 pts.", lastXorZ and "is" or "is not", lastXorZ and 0 or 25), lastXorZ and 0 or 25})
end

SLASH_NAMESCORE1 = "/namescore"
SlashCmdList["NAMESCORE"] = function(input)
	if not input or input == "" then
		if UnitName("target") then
			if not UnitPlayerControlled("target") then
				print("NameScore only grades players and their poor choices, not Blizzard's.")
				return
			end
			
			local score = NameScore.CalculateScore(UnitName("target"), "target") / 10
			NameScoreGradeFrame:Show()
			NameScoreModel:SetUnit("target")
			grade = nil
			for k, v in pairs(NameScore.Grades) do
				if score >= v[1] then
					grade = v[2]
				end
			end
			if not grade then
				grade = "F"
			end
			local tex, mark = grade:match("(%a)([%+%-]*)")
			NameScoreGrade1:SetTexture("Interface\\AddOns\\NameScore\\Textures\\"..tex)
			if mark ~= "" then NameScoreGrade2:SetTexture("Interface\\AddOns\\NameScore\\Textures\\"..(mark == "-" and "minus" or "plus")) NameScoreGrade2:Show() else NameScoreGrade2:Hide() end
			--[[local model, race = NameScoreModel, select(2, UnitRace("target"))
			model:SetUnit("target")
			if NameScore.Emotes[race][UnitSex("target")] then
				local score = (NameScore.CalculateScore(UnitName("target"), "target") / 10)
				if score >= 90 then
					model.updateFrame.sequence = NameScore.Emotes[race][UnitSex("target")]["cheer"]
				elseif score >= 70 then
					model.updateFrame.sequence = NameScore.Emotes[race][UnitSex("target")]["cry"]
				else
					model.updateFrame.sequence = NameScore.Emotes[race][UnitSex("target")]["beg"]
				end
				model.updateFrame:Show()
			end]]
			for k, v in pairs(breakdown) do
				_G["NameScoreExplString"..k]:SetText(v[1])
			end
			NameScoreTeacherString2:SetText(format("Write your name out, please, %s", UnitName("target")))
		else
			print("You must be targeting someone when you use this command.")
		end
	elseif NAMESCORE_DEBUG and input == "add" and UnitName("target") then
		tinsert(NameScoreAdds, {UnitName("target"), UnitRace("target"), select(1,UnitClass("target"))})
	--[[elseif NAMESCORE_DEBUG and input == "up" then
		local model = NameScoreModel
		model.seq = model.seq or 0
		model.seq = model.seq + 1
		model:SetSequence(model.seq)
		model:SetSequenceTime(model.seq, 0)
		model.updateFrame:SetScript("OnUpdate", function(self, elapsed)
			self.seqtime = (self.seqtime or 0) + elapsed
			model:AdvanceTime()
			model:SetSequenceTime(model.seq, self.seqtime)
		end)
		print(model.seq)]]
	elseif NAMESCORE_DEBUG then
		print("You should probably target who you're trying to analyze.")
	end
end

NameScore.Vowels = {
	["a"] = 6,
	["e"] = 7,
	["i"] = 8,
	["o"] = 9,
	["u"] = 10,
	["Y"] = 11,
	["y"] = 12,
	}

NameScore.Consonants = {
	["b"] = 14,
	["c"] = 16,
	["d"] = 18,
	["f"] = 20,
	["g"] = 22,
	["h"] = 24,
	["j"] = 26,
	["k"] = 28,
	["l"] = 30,
	["m"] = 32,
	["n"] = 34,
	["p"] = 36,
	["q"] = 38,
	["r"] = 40,
	["s"] = 42,
	["t"] = 44,
	["v"] = 46,
	["w"] = 48,
	["x"] = 50,
	["z"] = 52,
	}
	
NameScore.Foreign = {
	["\195\128"] = "a",
	["\195\129"] = "a",
	["\195\130"] = "a",
	["\195\131"] = "a",
	["\195\132"] = "a",
	["\195\133"] = "a",
	["\195\134"] = "ae",
	["\195\135"] = "c",
	["\195\136"] = "e",
	["\195\137"] = "e",
	["\195\138"] = "e",
	["\195\139"] = "e",
	["\195\140"] = "i",
	["\195\141"] = "i",
	["\195\142"] = "i",
	["\195\143"] = "i",
	["\195\144"] = "d",
	["\195\145"] = "n",
	["\195\146"] = "o",
	["\195\147"] = "o",
	["\195\148"] = "o",
	["\195\149"] = "o",
	["\195\150"] = "o",
	["\195\151"] = "x",
	["\195\152"] = "o",
	["\195\153"] = "u",
	["\195\154"] = "u",
	["\195\155"] = "u",
	["\195\156"] = "u",
	["\195\157"] = "y",
	["\195\158"] = "p",
	["\195\159"] = "b",
	["\195\160"] = "a",
	["\195\161"] = "a",
	["\195\162"] = "a",
	["\195\163"] = "a",
	["\195\164"] = "a",
	["\195\165"] = "a",
	["\195\166"] = "ae",
	["\195\167"] = "c",
	["\195\168"] = "e",
	["\195\169"] = "e",
	["\195\170"] = "e",
	["\195\171"] = "e",
	["\195\172"] = "i",
	["\195\173"] = "i",
	["\195\174"] = "i",
	["\195\175"] = "i",
	["\195\176"] = "d",
	["\195\177"] = "n",
	["\195\178"] = "o",
	["\195\179"] = "o",
	["\195\180"] = "o",
	["\195\180"] = "o",
	["\195\182"] = "o",
	["\195\184"] = "o",
	["\195\185"] = "u",
	["\195\186"] = "u",
	["\195\187"] = "u",
	["\195\188"] = "u",
	["\195\189"] = "y",
	["\195\190"] = "p",
	["\195\191"] = "y",
	}
	
NameScore.Grades = {
	{59, "F"},
	{60, "D-"},
	{65, "D"},
	{69, "D+"},
	{70, "C-"},
	{75, "C"},
	{79, "C+"},
	{80, "B-"},
	{85, "B"},
	{89, "B+"},
	{90, "A-"},
	{95, "A"},
	{100, "A+"},
}

local teacher = [[Interface\AddOns\NameScore\Fonts\StreetwiseBuddy.ttf]]

local gradeFrame = CreateFrame("Frame", "NameScoreGradeFrame", UIParent)
gradeFrame:SetHeight(1024)
gradeFrame:SetWidth(1024)
gradeFrame:SetPoint("CENTER", UIParent, "CENTER",125, -200)
gradeFrame:SetScale(1.25)
gradeFrame:SetFrameStrata("FULLSCREEN_DIALOG")
gradeFrame:Hide()
local paper = gradeFrame:CreateTexture("NameScoreGradePaper", "ARTWORK")
paper:SetTexture([[Interface\AddOns\NameScore\Textures\Paper]])
paper:SetHeight(1024)
paper:SetWidth(1024)
paper:SetPoint("CENTER")
local doneButton = CreateFrame("Button", "NameScoreDoneButton", gradeFrame)
doneButton:SetHeight(30)
doneButton:SetWidth(140)
doneButton:SetPoint("CENTER", -155, -63)
doneButton:SetScript("OnClick", function(self) self:GetParent():Hide() end)
local model = CreateFrame("PlayerModel", "NameScoreModel", gradeFrame)
model:SetHeight(80)
model:SetWidth(80)
model:SetUnit("player")
model:SetPoint("CENTER", NameScoreGradeFrame, "CENTER", -440, 460)
model:Show()
model.updateFrame = CreateFrame("Frame", nil, UIParent)
model.updateFrame:SetHeight(1)
model.updateFrame:SetWidth(1)
model.updateFrame:SetPoint("CENTER")
model.updateFrame:Hide()
local gradeGrade = CreateFrame("Frame","NSGG",gradeFrame)
gradeGrade:SetPoint("CENTER",5,5)
gradeGrade:SetScale(1.5)
gradeGrade:SetHeight(100)
gradeGrade:SetWidth(100)
local f1 = gradeFrame:CreateFontString("NameScoreTeacherString1")
f1:SetFont(teacher,18)
f1:SetTextColor(1,0,0)
f1:SetText("break (sp.)")
f1:SetPoint("TOPLEFT", 400, -20)
local f2 = gradeFrame:CreateFontString("NameScoreTeacherString2")
f2:SetFont(teacher,12)
f2:SetTextColor(1,0,0)
f2:SetPoint("CENTER",-275,405)
local f3 = gradeFrame:CreateFontString("NameScoreTeacherString3")
f3:SetFont(teacher, 12)
f3:SetTextColor(1,0,0)
f3:SetText("Good effort: Aesthetics")
f3:SetPoint("CENTER",10,360)
local f4 = gradeFrame:CreateFontString("NameScoreTeacherString4")
f4:SetFont(teacher, 12)
f4:SetTextColor(1,0,0)
f4:SetText("Miscellaneous")
f4:SetPoint("CENTER",-70,160)
local g1 = gradeFrame:CreateTexture("NameScoreGrade1","OVERLAY")
g1:SetHeight(64)
g1:SetWidth(64)
g1:SetPoint("CENTER",152,450)
local g2 = gradeFrame:CreateTexture("NameScoreGrade2","OVERLAY")
g2:SetHeight(64)
g2:SetWidth(64)
g2:SetPoint("CENTER",175,438)
for i = 1,16 do
	local fs = gradeFrame:CreateFontString("NameScoreExplString"..i)
	fs:SetFont(teacher,9)
	fs:SetTextColor(0,0,0)
	fs:SetJustifyH("LEFT")
	if i == 1 then
		fs:SetPoint("TOPLEFT", 30, -220)
	elseif i == 5 then
		fs:SetPoint("TOPLEFT", 30, -410)
	elseif i == 9 then
		fs:SetPoint("TOPLEFT", 370, -220)
	elseif i == 13 then
		fs:SetPoint("TOPLEFT", 370, -410)
	else
		fs:SetPoint("TOPLEFT", _G["NameScoreExplString"..(i-1)], "BOTTOMLEFT", 0, -10)
	end
end


NameScore.Emotes = {
	["BloodElf"] = {
		[3] = {
			["cheer"] = 110,
			["cry"] = 65,
			["cower"] = 144,
			["beg"] = 95,
		},
		[2] = {
			["cheer"] = 102,
			["cry"] = 104,
			["beg"] = 101,
			["cower"] = 147,
		},
	},
	["Scourge"] = {
		[2] = {
			["cheer"] = 53,
			["cry"] = 96,
			["beg"] = 101,
			["cower"] = 140,
		},
		[3] = {
			-- ["cheer"] = 89,
			["cheer"] = 140,
			["beg"] = 108,
			["cry"] = 112,
			["cower"] = 139,
		},
	},
	["Draenei"] = {
		[3] = {
			["cry"] = 23,
			["beg"] = 94,
			["cheer"] = 115,
			["cower"] = 143,
		},
		[2] = {
			["beg"] = 15,
			["cry"] = 18,
			["cheer"] = 125,
			["cower"] = 144,
		},
	},
	["Orc"] = {},
	["Troll"] = {},
	["NightElf"] = {},
	["Gnome"] = {},
	["Human"] = {},
	["Dwarf"] = {},
	["Tauren"] = {},
	}
